# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/evidence/v1beta1/evidence.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cosmos/evidence/v1beta1/evidence.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.amino import amino_pb2 as amino_dot_amino__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&cosmos/evidence/v1beta1/evidence.proto\x12\x17\x63osmos.evidence.v1beta1\x1a\x11\x61mino/amino.proto\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19\x63osmos_proto/cosmos.proto\"\xc1\x01\n\x0c\x45quivocation\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\x37\n\x04time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\r\xc8\xde\x1f\x00\x90\xdf\x1f\x01\xa8\xe7\xb0*\x01\x12\r\n\x05power\x18\x03 \x01(\x03\x12\x33\n\x11\x63onsensus_address\x18\x04 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString:$\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x8a\xe7\xb0*\x17\x63osmos-sdk/EquivocationB#Z\x1d\x63osmossdk.io/x/evidence/types\xa8\xe2\x1e\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.evidence.v1beta1.evidence_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\035cosmossdk.io/x/evidence/types\250\342\036\001'
  _globals['_EQUIVOCATION'].fields_by_name['time']._loaded_options = None
  _globals['_EQUIVOCATION'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001\250\347\260*\001'
  _globals['_EQUIVOCATION'].fields_by_name['consensus_address']._loaded_options = None
  _globals['_EQUIVOCATION'].fields_by_name['consensus_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_EQUIVOCATION']._loaded_options = None
  _globals['_EQUIVOCATION']._serialized_options = b'\210\240\037\000\350\240\037\000\212\347\260*\027cosmos-sdk/Equivocation'
  _globals['_EQUIVOCATION']._serialized_start=169
  _globals['_EQUIVOCATION']._serialized_end=362
# @@protoc_insertion_point(module_scope)



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.cosmos.staking.v1beta1 import staking_pb2 as _staking_pb2
from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.amino import amino_pb2 as _amino_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GenesisState(_message.Message):
    __slots__ = ("params", "last_total_power", "last_validator_powers", "validators", "delegations", "unbonding_delegations", "redelegations", "exported")
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    LAST_TOTAL_POWER_FIELD_NUMBER: _ClassVar[int]
    LAST_VALIDATOR_POWERS_FIELD_NUMBER: _ClassVar[int]
    VALIDATORS_FIELD_NUMBER: _ClassVar[int]
    DELEGATIONS_FIELD_NUMBER: _ClassVar[int]
    UNBONDING_DELEGATIONS_FIELD_NUMBER: _ClassVar[int]
    REDELEGATIONS_FIELD_NUMBER: _ClassVar[int]
    EXPORTED_FIELD_NUMBER: _ClassVar[int]
    params: _staking_pb2.Params
    last_total_power: bytes
    last_validator_powers: _containers.RepeatedCompositeFieldContainer[LastValidatorPower]
    validators: _containers.RepeatedCompositeFieldContainer[_staking_pb2.Validator]
    delegations: _containers.RepeatedCompositeFieldContainer[_staking_pb2.Delegation]
    unbonding_delegations: _containers.RepeatedCompositeFieldContainer[_staking_pb2.UnbondingDelegation]
    redelegations: _containers.RepeatedCompositeFieldContainer[_staking_pb2.Redelegation]
    exported: bool
    def __init__(self, params: _Optional[_Union[_staking_pb2.Params, _Mapping]] = ..., last_total_power: _Optional[bytes] = ..., last_validator_powers: _Optional[_Iterable[_Union[LastValidatorPower, _Mapping]]] = ..., validators: _Optional[_Iterable[_Union[_staking_pb2.Validator, _Mapping]]] = ..., delegations: _Optional[_Iterable[_Union[_staking_pb2.Delegation, _Mapping]]] = ..., unbonding_delegations: _Optional[_Iterable[_Union[_staking_pb2.UnbondingDelegation, _Mapping]]] = ..., redelegations: _Optional[_Iterable[_Union[_staking_pb2.Redelegation, _Mapping]]] = ..., exported: bool = ...) -> None: ...

class LastValidatorPower(_message.Message):
    __slots__ = ("address", "power")
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    POWER_FIELD_NUMBER: _ClassVar[int]
    address: str
    power: int
    def __init__(self, address: _Optional[str] = ..., power: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/clob/tx.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/clob/tx.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.dydxprotocol.clob import block_rate_limit_config_pb2 as dydxprotocol_dot_clob_dot_block__rate__limit__config__pb2
from v4_proto.dydxprotocol.clob import clob_pair_pb2 as dydxprotocol_dot_clob_dot_clob__pair__pb2
from v4_proto.dydxprotocol.clob import equity_tier_limit_config_pb2 as dydxprotocol_dot_clob_dot_equity__tier__limit__config__pb2
from v4_proto.dydxprotocol.clob import matches_pb2 as dydxprotocol_dot_clob_dot_matches__pb2
from v4_proto.dydxprotocol.clob import order_pb2 as dydxprotocol_dot_clob_dot_order__pb2
from v4_proto.dydxprotocol.clob import order_removals_pb2 as dydxprotocol_dot_clob_dot_order__removals__pb2
from v4_proto.dydxprotocol.clob import liquidations_config_pb2 as dydxprotocol_dot_clob_dot_liquidations__config__pb2
from v4_proto.dydxprotocol.subaccounts import subaccount_pb2 as dydxprotocol_dot_subaccounts_dot_subaccount__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x64ydxprotocol/clob/tx.proto\x12\x11\x64ydxprotocol.clob\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x14gogoproto/gogo.proto\x1a/dydxprotocol/clob/block_rate_limit_config.proto\x1a!dydxprotocol/clob/clob_pair.proto\x1a\x30\x64ydxprotocol/clob/equity_tier_limit_config.proto\x1a\x1f\x64ydxprotocol/clob/matches.proto\x1a\x1d\x64ydxprotocol/clob/order.proto\x1a&dydxprotocol/clob/order_removals.proto\x1a+dydxprotocol/clob/liquidations_config.proto\x1a)dydxprotocol/subaccounts/subaccount.proto\"\x86\x01\n\x11MsgCreateClobPair\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x34\n\tclob_pair\x18\x02 \x01(\x0b\x32\x1b.dydxprotocol.clob.ClobPairB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"\x1b\n\x19MsgCreateClobPairResponse\"X\n\x15MsgProposedOperations\x12?\n\x10operations_queue\x18\x01 \x03(\x0b\x32\x1f.dydxprotocol.clob.OperationRawB\x04\xc8\xde\x1f\x00\"\x1f\n\x1dMsgProposedOperationsResponse\">\n\rMsgPlaceOrder\x12-\n\x05order\x18\x01 \x01(\x0b\x32\x18.dydxprotocol.clob.OrderB\x04\xc8\xde\x1f\x00\"\x17\n\x15MsgPlaceOrderResponse\"\x8f\x01\n\x0eMsgCancelOrder\x12\x32\n\x08order_id\x18\x01 \x01(\x0b\x32\x1a.dydxprotocol.clob.OrderIdB\x04\xc8\xde\x1f\x00\x12\x18\n\x0egood_til_block\x18\x02 \x01(\rH\x00\x12\x1d\n\x13good_til_block_time\x18\x03 \x01(\x07H\x00\x42\x10\n\x0egood_til_oneof\"\x18\n\x16MsgCancelOrderResponse\"\xae\x01\n\x0eMsgBatchCancel\x12\x43\n\rsubaccount_id\x18\x01 \x01(\x0b\x32&.dydxprotocol.subaccounts.SubaccountIdB\x04\xc8\xde\x1f\x00\x12?\n\x12short_term_cancels\x18\x02 \x03(\x0b\x32\x1d.dydxprotocol.clob.OrderBatchB\x04\xc8\xde\x1f\x00\x12\x16\n\x0egood_til_block\x18\x03 \x01(\r\"6\n\nOrderBatch\x12\x14\n\x0c\x63lob_pair_id\x18\x01 \x01(\r\x12\x12\n\nclient_ids\x18\x02 \x03(\r\"\x8f\x01\n\x16MsgBatchCancelResponse\x12;\n\x14short_term_succeeded\x18\x01 \x03(\x0b\x32\x1d.dydxprotocol.clob.OrderBatch\x12\x38\n\x11short_term_failed\x18\x02 \x03(\x0b\x32\x1d.dydxprotocol.clob.OrderBatch\"\x86\x01\n\x11MsgUpdateClobPair\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x34\n\tclob_pair\x18\x02 \x01(\x0b\x32\x1b.dydxprotocol.clob.ClobPairB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"\x1b\n\x19MsgUpdateClobPairResponse\"\xaa\x01\n\x0cOperationRaw\x12-\n\x05match\x18\x01 \x01(\x0b\x32\x1c.dydxprotocol.clob.ClobMatchH\x00\x12$\n\x1ashort_term_order_placement\x18\x02 \x01(\x0cH\x00\x12\x38\n\rorder_removal\x18\x03 \x01(\x0b\x32\x1f.dydxprotocol.clob.OrderRemovalH\x00\x42\x0b\n\toperation\"\xbd\x01\n%MsgUpdateEquityTierLimitConfiguration\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12W\n\x18\x65quity_tier_limit_config\x18\x02 \x01(\x0b\x32/.dydxprotocol.clob.EquityTierLimitConfigurationB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"/\n-MsgUpdateEquityTierLimitConfigurationResponse\"\xba\x01\n$MsgUpdateBlockRateLimitConfiguration\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12U\n\x17\x62lock_rate_limit_config\x18\x03 \x01(\x0b\x32..dydxprotocol.clob.BlockRateLimitConfigurationB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\".\n,MsgUpdateBlockRateLimitConfigurationResponse\"\xa4\x01\n\x1bMsgUpdateLiquidationsConfig\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12H\n\x13liquidations_config\x18\x02 \x01(\x0b\x32%.dydxprotocol.clob.LiquidationsConfigB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"%\n#MsgUpdateLiquidationsConfigResponse2\x9f\x08\n\x03Msg\x12p\n\x12ProposedOperations\x12(.dydxprotocol.clob.MsgProposedOperations\x1a\x30.dydxprotocol.clob.MsgProposedOperationsResponse\x12X\n\nPlaceOrder\x12 .dydxprotocol.clob.MsgPlaceOrder\x1a(.dydxprotocol.clob.MsgPlaceOrderResponse\x12[\n\x0b\x43\x61ncelOrder\x12!.dydxprotocol.clob.MsgCancelOrder\x1a).dydxprotocol.clob.MsgCancelOrderResponse\x12[\n\x0b\x42\x61tchCancel\x12!.dydxprotocol.clob.MsgBatchCancel\x1a).dydxprotocol.clob.MsgBatchCancelResponse\x12\x64\n\x0e\x43reateClobPair\x12$.dydxprotocol.clob.MsgCreateClobPair\x1a,.dydxprotocol.clob.MsgCreateClobPairResponse\x12\x64\n\x0eUpdateClobPair\x12$.dydxprotocol.clob.MsgUpdateClobPair\x1a,.dydxprotocol.clob.MsgUpdateClobPairResponse\x12\xa0\x01\n\"UpdateEquityTierLimitConfiguration\x12\x38.dydxprotocol.clob.MsgUpdateEquityTierLimitConfiguration\x1a@.dydxprotocol.clob.MsgUpdateEquityTierLimitConfigurationResponse\x12\x9d\x01\n!UpdateBlockRateLimitConfiguration\x12\x37.dydxprotocol.clob.MsgUpdateBlockRateLimitConfiguration\x1a?.dydxprotocol.clob.MsgUpdateBlockRateLimitConfigurationResponse\x12\x82\x01\n\x18UpdateLiquidationsConfig\x12..dydxprotocol.clob.MsgUpdateLiquidationsConfig\x1a\x36.dydxprotocol.clob.MsgUpdateLiquidationsConfigResponseB8Z6github.com/dydxprotocol/v4-chain/protocol/x/clob/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.clob.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z6github.com/dydxprotocol/v4-chain/protocol/x/clob/types'
  _globals['_MSGCREATECLOBPAIR'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGCREATECLOBPAIR'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGCREATECLOBPAIR'].fields_by_name['clob_pair']._loaded_options = None
  _globals['_MSGCREATECLOBPAIR'].fields_by_name['clob_pair']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCREATECLOBPAIR']._loaded_options = None
  _globals['_MSGCREATECLOBPAIR']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGPROPOSEDOPERATIONS'].fields_by_name['operations_queue']._loaded_options = None
  _globals['_MSGPROPOSEDOPERATIONS'].fields_by_name['operations_queue']._serialized_options = b'\310\336\037\000'
  _globals['_MSGPLACEORDER'].fields_by_name['order']._loaded_options = None
  _globals['_MSGPLACEORDER'].fields_by_name['order']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCANCELORDER'].fields_by_name['order_id']._loaded_options = None
  _globals['_MSGCANCELORDER'].fields_by_name['order_id']._serialized_options = b'\310\336\037\000'
  _globals['_MSGBATCHCANCEL'].fields_by_name['subaccount_id']._loaded_options = None
  _globals['_MSGBATCHCANCEL'].fields_by_name['subaccount_id']._serialized_options = b'\310\336\037\000'
  _globals['_MSGBATCHCANCEL'].fields_by_name['short_term_cancels']._loaded_options = None
  _globals['_MSGBATCHCANCEL'].fields_by_name['short_term_cancels']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATECLOBPAIR'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATECLOBPAIR'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATECLOBPAIR'].fields_by_name['clob_pair']._loaded_options = None
  _globals['_MSGUPDATECLOBPAIR'].fields_by_name['clob_pair']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATECLOBPAIR']._loaded_options = None
  _globals['_MSGUPDATECLOBPAIR']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGUPDATEEQUITYTIERLIMITCONFIGURATION'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEEQUITYTIERLIMITCONFIGURATION'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEEQUITYTIERLIMITCONFIGURATION'].fields_by_name['equity_tier_limit_config']._loaded_options = None
  _globals['_MSGUPDATEEQUITYTIERLIMITCONFIGURATION'].fields_by_name['equity_tier_limit_config']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEEQUITYTIERLIMITCONFIGURATION']._loaded_options = None
  _globals['_MSGUPDATEEQUITYTIERLIMITCONFIGURATION']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGUPDATEBLOCKRATELIMITCONFIGURATION'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEBLOCKRATELIMITCONFIGURATION'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEBLOCKRATELIMITCONFIGURATION'].fields_by_name['block_rate_limit_config']._loaded_options = None
  _globals['_MSGUPDATEBLOCKRATELIMITCONFIGURATION'].fields_by_name['block_rate_limit_config']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEBLOCKRATELIMITCONFIGURATION']._loaded_options = None
  _globals['_MSGUPDATEBLOCKRATELIMITCONFIGURATION']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGUPDATELIQUIDATIONSCONFIG'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATELIQUIDATIONSCONFIG'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATELIQUIDATIONSCONFIG'].fields_by_name['liquidations_config']._loaded_options = None
  _globals['_MSGUPDATELIQUIDATIONSCONFIG'].fields_by_name['liquidations_config']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATELIQUIDATIONSCONFIG']._loaded_options = None
  _globals['_MSGUPDATELIQUIDATIONSCONFIG']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGCREATECLOBPAIR']._serialized_start=450
  _globals['_MSGCREATECLOBPAIR']._serialized_end=584
  _globals['_MSGCREATECLOBPAIRRESPONSE']._serialized_start=586
  _globals['_MSGCREATECLOBPAIRRESPONSE']._serialized_end=613
  _globals['_MSGPROPOSEDOPERATIONS']._serialized_start=615
  _globals['_MSGPROPOSEDOPERATIONS']._serialized_end=703
  _globals['_MSGPROPOSEDOPERATIONSRESPONSE']._serialized_start=705
  _globals['_MSGPROPOSEDOPERATIONSRESPONSE']._serialized_end=736
  _globals['_MSGPLACEORDER']._serialized_start=738
  _globals['_MSGPLACEORDER']._serialized_end=800
  _globals['_MSGPLACEORDERRESPONSE']._serialized_start=802
  _globals['_MSGPLACEORDERRESPONSE']._serialized_end=825
  _globals['_MSGCANCELORDER']._serialized_start=828
  _globals['_MSGCANCELORDER']._serialized_end=971
  _globals['_MSGCANCELORDERRESPONSE']._serialized_start=973
  _globals['_MSGCANCELORDERRESPONSE']._serialized_end=997
  _globals['_MSGBATCHCANCEL']._serialized_start=1000
  _globals['_MSGBATCHCANCEL']._serialized_end=1174
  _globals['_ORDERBATCH']._serialized_start=1176
  _globals['_ORDERBATCH']._serialized_end=1230
  _globals['_MSGBATCHCANCELRESPONSE']._serialized_start=1233
  _globals['_MSGBATCHCANCELRESPONSE']._serialized_end=1376
  _globals['_MSGUPDATECLOBPAIR']._serialized_start=1379
  _globals['_MSGUPDATECLOBPAIR']._serialized_end=1513
  _globals['_MSGUPDATECLOBPAIRRESPONSE']._serialized_start=1515
  _globals['_MSGUPDATECLOBPAIRRESPONSE']._serialized_end=1542
  _globals['_OPERATIONRAW']._serialized_start=1545
  _globals['_OPERATIONRAW']._serialized_end=1715
  _globals['_MSGUPDATEEQUITYTIERLIMITCONFIGURATION']._serialized_start=1718
  _globals['_MSGUPDATEEQUITYTIERLIMITCONFIGURATION']._serialized_end=1907
  _globals['_MSGUPDATEEQUITYTIERLIMITCONFIGURATIONRESPONSE']._serialized_start=1909
  _globals['_MSGUPDATEEQUITYTIERLIMITCONFIGURATIONRESPONSE']._serialized_end=1956
  _globals['_MSGUPDATEBLOCKRATELIMITCONFIGURATION']._serialized_start=1959
  _globals['_MSGUPDATEBLOCKRATELIMITCONFIGURATION']._serialized_end=2145
  _globals['_MSGUPDATEBLOCKRATELIMITCONFIGURATIONRESPONSE']._serialized_start=2147
  _globals['_MSGUPDATEBLOCKRATELIMITCONFIGURATIONRESPONSE']._serialized_end=2193
  _globals['_MSGUPDATELIQUIDATIONSCONFIG']._serialized_start=2196
  _globals['_MSGUPDATELIQUIDATIONSCONFIG']._serialized_end=2360
  _globals['_MSGUPDATELIQUIDATIONSCONFIGRESPONSE']._serialized_start=2362
  _globals['_MSGUPDATELIQUIDATIONSCONFIGRESPONSE']._serialized_end=2399
  _globals['_MSG']._serialized_start=2402
  _globals['_MSG']._serialized_end=3457
# @@protoc_insertion_point(module_scope)



from v4_proto.dydxprotocol.subaccounts import streaming_pb2 as _streaming_pb2
from v4_proto.dydxprotocol.prices import streaming_pb2 as _streaming_pb2_1
from v4_proto.dydxprotocol.clob import query_pb2 as _query_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class StagedFinalizeBlockEvent(_message.Message):
    __slots__ = ("order_fill", "subaccount_update", "orderbook_update", "price_update")
    ORDER_FILL_FIELD_NUMBER: _ClassVar[int]
    SUBACCOUNT_UPDATE_FIELD_NUMBER: _ClassVar[int]
    ORDERBOOK_UPDATE_FIELD_NUMBER: _ClassVar[int]
    PRICE_UPDATE_FIELD_NUMBER: _ClassVar[int]
    order_fill: _query_pb2.StreamOrderbookFill
    subaccount_update: _streaming_pb2.StreamSubaccountUpdate
    orderbook_update: _query_pb2.StreamOrderbookUpdate
    price_update: _streaming_pb2_1.StreamPriceUpdate
    def __init__(self, order_fill: _Optional[_Union[_query_pb2.StreamOrderbookFill, _Mapping]] = ..., subaccount_update: _Optional[_Union[_streaming_pb2.StreamSubaccountUpdate, _Mapping]] = ..., orderbook_update: _Optional[_Union[_query_pb2.StreamOrderbookUpdate, _Mapping]] = ..., price_update: _Optional[_Union[_streaming_pb2_1.StreamPriceUpdate, _Mapping]] = ...) -> None: ...



import datetime

from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import any_pb2 as _any_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from v4_proto.amino import amino_pb2 as _amino_pb2
from v4_proto.tendermint.types import types_pb2 as _types_pb2
from v4_proto.tendermint.abci import types_pb2 as _types_pb2_1
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class BondStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    BOND_STATUS_UNSPECIFIED: _ClassVar[BondStatus]
    BOND_STATUS_UNBONDED: _ClassVar[BondStatus]
    BOND_STATUS_UNBONDING: _ClassVar[BondStatus]
    BOND_STATUS_BONDED: _ClassVar[BondStatus]

class Infraction(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    INFRACTION_UNSPECIFIED: _ClassVar[Infraction]
    INFRACTION_DOUBLE_SIGN: _ClassVar[Infraction]
    INFRACTION_DOWNTIME: _ClassVar[Infraction]
BOND_STATUS_UNSPECIFIED: BondStatus
BOND_STATUS_UNBONDED: BondStatus
BOND_STATUS_UNBONDING: BondStatus
BOND_STATUS_BONDED: BondStatus
INFRACTION_UNSPECIFIED: Infraction
INFRACTION_DOUBLE_SIGN: Infraction
INFRACTION_DOWNTIME: Infraction

class HistoricalInfo(_message.Message):
    __slots__ = ("header", "valset")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    VALSET_FIELD_NUMBER: _ClassVar[int]
    header: _types_pb2.Header
    valset: _containers.RepeatedCompositeFieldContainer[Validator]
    def __init__(self, header: _Optional[_Union[_types_pb2.Header, _Mapping]] = ..., valset: _Optional[_Iterable[_Union[Validator, _Mapping]]] = ...) -> None: ...

class CommissionRates(_message.Message):
    __slots__ = ("rate", "max_rate", "max_change_rate")
    RATE_FIELD_NUMBER: _ClassVar[int]
    MAX_RATE_FIELD_NUMBER: _ClassVar[int]
    MAX_CHANGE_RATE_FIELD_NUMBER: _ClassVar[int]
    rate: str
    max_rate: str
    max_change_rate: str
    def __init__(self, rate: _Optional[str] = ..., max_rate: _Optional[str] = ..., max_change_rate: _Optional[str] = ...) -> None: ...

class Commission(_message.Message):
    __slots__ = ("commission_rates", "update_time")
    COMMISSION_RATES_FIELD_NUMBER: _ClassVar[int]
    UPDATE_TIME_FIELD_NUMBER: _ClassVar[int]
    commission_rates: CommissionRates
    update_time: _timestamp_pb2.Timestamp
    def __init__(self, commission_rates: _Optional[_Union[CommissionRates, _Mapping]] = ..., update_time: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class Description(_message.Message):
    __slots__ = ("moniker", "identity", "website", "security_contact", "details")
    MONIKER_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_FIELD_NUMBER: _ClassVar[int]
    WEBSITE_FIELD_NUMBER: _ClassVar[int]
    SECURITY_CONTACT_FIELD_NUMBER: _ClassVar[int]
    DETAILS_FIELD_NUMBER: _ClassVar[int]
    moniker: str
    identity: str
    website: str
    security_contact: str
    details: str
    def __init__(self, moniker: _Optional[str] = ..., identity: _Optional[str] = ..., website: _Optional[str] = ..., security_contact: _Optional[str] = ..., details: _Optional[str] = ...) -> None: ...

class Validator(_message.Message):
    __slots__ = ("operator_address", "consensus_pubkey", "jailed", "status", "tokens", "delegator_shares", "description", "unbonding_height", "unbonding_time", "commission", "min_self_delegation", "unbonding_on_hold_ref_count", "unbonding_ids")
    OPERATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    CONSENSUS_PUBKEY_FIELD_NUMBER: _ClassVar[int]
    JAILED_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    TOKENS_FIELD_NUMBER: _ClassVar[int]
    DELEGATOR_SHARES_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    UNBONDING_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    UNBONDING_TIME_FIELD_NUMBER: _ClassVar[int]
    COMMISSION_FIELD_NUMBER: _ClassVar[int]
    MIN_SELF_DELEGATION_FIELD_NUMBER: _ClassVar[int]
    UNBONDING_ON_HOLD_REF_COUNT_FIELD_NUMBER: _ClassVar[int]
    UNBONDING_IDS_FIELD_NUMBER: _ClassVar[int]
    operator_address: str
    consensus_pubkey: _any_pb2.Any
    jailed: bool
    status: BondStatus
    tokens: str
    delegator_shares: str
    description: Description
    unbonding_height: int
    unbonding_time: _timestamp_pb2.Timestamp
    commission: Commission
    min_self_delegation: str
    unbonding_on_hold_ref_count: int
    unbonding_ids: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, operator_address: _Optional[str] = ..., consensus_pubkey: _Optional[_Union[_any_pb2.Any, _Mapping]] = ..., jailed: bool = ..., status: _Optional[_Union[BondStatus, str]] = ..., tokens: _Optional[str] = ..., delegator_shares: _Optional[str] = ..., description: _Optional[_Union[Description, _Mapping]] = ..., unbonding_height: _Optional[int] = ..., unbonding_time: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., commission: _Optional[_Union[Commission, _Mapping]] = ..., min_self_delegation: _Optional[str] = ..., unbonding_on_hold_ref_count: _Optional[int] = ..., unbonding_ids: _Optional[_Iterable[int]] = ...) -> None: ...

class ValAddresses(_message.Message):
    __slots__ = ("addresses",)
    ADDRESSES_FIELD_NUMBER: _ClassVar[int]
    addresses: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, addresses: _Optional[_Iterable[str]] = ...) -> None: ...

class DVPair(_message.Message):
    __slots__ = ("delegator_address", "validator_address")
    DELEGATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    delegator_address: str
    validator_address: str
    def __init__(self, delegator_address: _Optional[str] = ..., validator_address: _Optional[str] = ...) -> None: ...

class DVPairs(_message.Message):
    __slots__ = ("pairs",)
    PAIRS_FIELD_NUMBER: _ClassVar[int]
    pairs: _containers.RepeatedCompositeFieldContainer[DVPair]
    def __init__(self, pairs: _Optional[_Iterable[_Union[DVPair, _Mapping]]] = ...) -> None: ...

class DVVTriplet(_message.Message):
    __slots__ = ("delegator_address", "validator_src_address", "validator_dst_address")
    DELEGATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_SRC_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_DST_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    delegator_address: str
    validator_src_address: str
    validator_dst_address: str
    def __init__(self, delegator_address: _Optional[str] = ..., validator_src_address: _Optional[str] = ..., validator_dst_address: _Optional[str] = ...) -> None: ...

class DVVTriplets(_message.Message):
    __slots__ = ("triplets",)
    TRIPLETS_FIELD_NUMBER: _ClassVar[int]
    triplets: _containers.RepeatedCompositeFieldContainer[DVVTriplet]
    def __init__(self, triplets: _Optional[_Iterable[_Union[DVVTriplet, _Mapping]]] = ...) -> None: ...

class Delegation(_message.Message):
    __slots__ = ("delegator_address", "validator_address", "shares")
    DELEGATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    SHARES_FIELD_NUMBER: _ClassVar[int]
    delegator_address: str
    validator_address: str
    shares: str
    def __init__(self, delegator_address: _Optional[str] = ..., validator_address: _Optional[str] = ..., shares: _Optional[str] = ...) -> None: ...

class UnbondingDelegation(_message.Message):
    __slots__ = ("delegator_address", "validator_address", "entries")
    DELEGATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    ENTRIES_FIELD_NUMBER: _ClassVar[int]
    delegator_address: str
    validator_address: str
    entries: _containers.RepeatedCompositeFieldContainer[UnbondingDelegationEntry]
    def __init__(self, delegator_address: _Optional[str] = ..., validator_address: _Optional[str] = ..., entries: _Optional[_Iterable[_Union[UnbondingDelegationEntry, _Mapping]]] = ...) -> None: ...

class UnbondingDelegationEntry(_message.Message):
    __slots__ = ("creation_height", "completion_time", "initial_balance", "balance", "unbonding_id", "unbonding_on_hold_ref_count")
    CREATION_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    COMPLETION_TIME_FIELD_NUMBER: _ClassVar[int]
    INITIAL_BALANCE_FIELD_NUMBER: _ClassVar[int]
    BALANCE_FIELD_NUMBER: _ClassVar[int]
    UNBONDING_ID_FIELD_NUMBER: _ClassVar[int]
    UNBONDING_ON_HOLD_REF_COUNT_FIELD_NUMBER: _ClassVar[int]
    creation_height: int
    completion_time: _timestamp_pb2.Timestamp
    initial_balance: str
    balance: str
    unbonding_id: int
    unbonding_on_hold_ref_count: int
    def __init__(self, creation_height: _Optional[int] = ..., completion_time: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., initial_balance: _Optional[str] = ..., balance: _Optional[str] = ..., unbonding_id: _Optional[int] = ..., unbonding_on_hold_ref_count: _Optional[int] = ...) -> None: ...

class RedelegationEntry(_message.Message):
    __slots__ = ("creation_height", "completion_time", "initial_balance", "shares_dst", "unbonding_id", "unbonding_on_hold_ref_count")
    CREATION_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    COMPLETION_TIME_FIELD_NUMBER: _ClassVar[int]
    INITIAL_BALANCE_FIELD_NUMBER: _ClassVar[int]
    SHARES_DST_FIELD_NUMBER: _ClassVar[int]
    UNBONDING_ID_FIELD_NUMBER: _ClassVar[int]
    UNBONDING_ON_HOLD_REF_COUNT_FIELD_NUMBER: _ClassVar[int]
    creation_height: int
    completion_time: _timestamp_pb2.Timestamp
    initial_balance: str
    shares_dst: str
    unbonding_id: int
    unbonding_on_hold_ref_count: int
    def __init__(self, creation_height: _Optional[int] = ..., completion_time: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., initial_balance: _Optional[str] = ..., shares_dst: _Optional[str] = ..., unbonding_id: _Optional[int] = ..., unbonding_on_hold_ref_count: _Optional[int] = ...) -> None: ...

class Redelegation(_message.Message):
    __slots__ = ("delegator_address", "validator_src_address", "validator_dst_address", "entries")
    DELEGATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_SRC_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_DST_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    ENTRIES_FIELD_NUMBER: _ClassVar[int]
    delegator_address: str
    validator_src_address: str
    validator_dst_address: str
    entries: _containers.RepeatedCompositeFieldContainer[RedelegationEntry]
    def __init__(self, delegator_address: _Optional[str] = ..., validator_src_address: _Optional[str] = ..., validator_dst_address: _Optional[str] = ..., entries: _Optional[_Iterable[_Union[RedelegationEntry, _Mapping]]] = ...) -> None: ...

class Params(_message.Message):
    __slots__ = ("unbonding_time", "max_validators", "max_entries", "historical_entries", "bond_denom", "min_commission_rate")
    UNBONDING_TIME_FIELD_NUMBER: _ClassVar[int]
    MAX_VALIDATORS_FIELD_NUMBER: _ClassVar[int]
    MAX_ENTRIES_FIELD_NUMBER: _ClassVar[int]
    HISTORICAL_ENTRIES_FIELD_NUMBER: _ClassVar[int]
    BOND_DENOM_FIELD_NUMBER: _ClassVar[int]
    MIN_COMMISSION_RATE_FIELD_NUMBER: _ClassVar[int]
    unbonding_time: _duration_pb2.Duration
    max_validators: int
    max_entries: int
    historical_entries: int
    bond_denom: str
    min_commission_rate: str
    def __init__(self, unbonding_time: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ..., max_validators: _Optional[int] = ..., max_entries: _Optional[int] = ..., historical_entries: _Optional[int] = ..., bond_denom: _Optional[str] = ..., min_commission_rate: _Optional[str] = ...) -> None: ...

class DelegationResponse(_message.Message):
    __slots__ = ("delegation", "balance")
    DELEGATION_FIELD_NUMBER: _ClassVar[int]
    BALANCE_FIELD_NUMBER: _ClassVar[int]
    delegation: Delegation
    balance: _coin_pb2.Coin
    def __init__(self, delegation: _Optional[_Union[Delegation, _Mapping]] = ..., balance: _Optional[_Union[_coin_pb2.Coin, _Mapping]] = ...) -> None: ...

class RedelegationEntryResponse(_message.Message):
    __slots__ = ("redelegation_entry", "balance")
    REDELEGATION_ENTRY_FIELD_NUMBER: _ClassVar[int]
    BALANCE_FIELD_NUMBER: _ClassVar[int]
    redelegation_entry: RedelegationEntry
    balance: str
    def __init__(self, redelegation_entry: _Optional[_Union[RedelegationEntry, _Mapping]] = ..., balance: _Optional[str] = ...) -> None: ...

class RedelegationResponse(_message.Message):
    __slots__ = ("redelegation", "entries")
    REDELEGATION_FIELD_NUMBER: _ClassVar[int]
    ENTRIES_FIELD_NUMBER: _ClassVar[int]
    redelegation: Redelegation
    entries: _containers.RepeatedCompositeFieldContainer[RedelegationEntryResponse]
    def __init__(self, redelegation: _Optional[_Union[Redelegation, _Mapping]] = ..., entries: _Optional[_Iterable[_Union[RedelegationEntryResponse, _Mapping]]] = ...) -> None: ...

class Pool(_message.Message):
    __slots__ = ("not_bonded_tokens", "bonded_tokens")
    NOT_BONDED_TOKENS_FIELD_NUMBER: _ClassVar[int]
    BONDED_TOKENS_FIELD_NUMBER: _ClassVar[int]
    not_bonded_tokens: str
    bonded_tokens: str
    def __init__(self, not_bonded_tokens: _Optional[str] = ..., bonded_tokens: _Optional[str] = ...) -> None: ...

class ValidatorUpdates(_message.Message):
    __slots__ = ("updates",)
    UPDATES_FIELD_NUMBER: _ClassVar[int]
    updates: _containers.RepeatedCompositeFieldContainer[_types_pb2_1.ValidatorUpdate]
    def __init__(self, updates: _Optional[_Iterable[_Union[_types_pb2_1.ValidatorUpdate, _Mapping]]] = ...) -> None: ...



from v4_proto.cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from google.protobuf import any_pb2 as _any_pb2
from v4_proto.google.api import annotations_pb2 as _annotations_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryEvidenceRequest(_message.Message):
    __slots__ = ("evidence_hash", "hash")
    EVIDENCE_HASH_FIELD_NUMBER: _ClassVar[int]
    HASH_FIELD_NUMBER: _ClassVar[int]
    evidence_hash: bytes
    hash: str
    def __init__(self, evidence_hash: _Optional[bytes] = ..., hash: _Optional[str] = ...) -> None: ...

class QueryEvidenceResponse(_message.Message):
    __slots__ = ("evidence",)
    EVIDENCE_FIELD_NUMBER: _ClassVar[int]
    evidence: _any_pb2.Any
    def __init__(self, evidence: _Optional[_Union[_any_pb2.Any, _Mapping]] = ...) -> None: ...

class QueryAllEvidenceRequest(_message.Message):
    __slots__ = ("pagination",)
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest
    def __init__(self, pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryAllEvidenceResponse(_message.Message):
    __slots__ = ("evidence", "pagination")
    EVIDENCE_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    evidence: _containers.RepeatedCompositeFieldContainer[_any_pb2.Any]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, evidence: _Optional[_Iterable[_Union[_any_pb2.Any, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.cosmos.authz.v1beta1 import authz_pb2 as _authz_pb2
from v4_proto.amino import amino_pb2 as _amino_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GenesisState(_message.Message):
    __slots__ = ("authorization",)
    AUTHORIZATION_FIELD_NUMBER: _ClassVar[int]
    authorization: _containers.RepeatedCompositeFieldContainer[_authz_pb2.GrantAuthorization]
    def __init__(self, authorization: _Optional[_Iterable[_Union[_authz_pb2.GrantAuthorization, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/group/v1/types.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cosmos/group/v1/types.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from v4_proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x63osmos/group/v1/types.proto\x12\x0f\x63osmos.group.v1\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x19google/protobuf/any.proto\x1a\x11\x61mino/amino.proto\"\x92\x01\n\x06Member\x12)\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x0e\n\x06weight\x18\x02 \x01(\t\x12\x10\n\x08metadata\x18\x03 \x01(\t\x12;\n\x08\x61\x64\x64\x65\x64_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\r\xc8\xde\x1f\x00\x90\xdf\x1f\x01\xa8\xe7\xb0*\x01\"\\\n\rMemberRequest\x12)\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x0e\n\x06weight\x18\x02 \x01(\t\x12\x10\n\x08metadata\x18\x03 \x01(\t\"\xb0\x01\n\x17ThresholdDecisionPolicy\x12\x11\n\tthreshold\x18\x01 \x01(\t\x12\x37\n\x07windows\x18\x02 \x01(\x0b\x32&.cosmos.group.v1.DecisionPolicyWindows:I\xca\xb4-\x1e\x63osmos.group.v1.DecisionPolicy\x8a\xe7\xb0*\"cosmos-sdk/ThresholdDecisionPolicy\"\xb3\x01\n\x18PercentageDecisionPolicy\x12\x12\n\npercentage\x18\x01 \x01(\t\x12\x37\n\x07windows\x18\x02 \x01(\x0b\x32&.cosmos.group.v1.DecisionPolicyWindows:J\xca\xb4-\x1e\x63osmos.group.v1.DecisionPolicy\x8a\xe7\xb0*#cosmos-sdk/PercentageDecisionPolicy\"\xa0\x01\n\x15\x44\x65\x63isionPolicyWindows\x12?\n\rvoting_period\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\r\xc8\xde\x1f\x00\x98\xdf\x1f\x01\xa8\xe7\xb0*\x01\x12\x46\n\x14min_execution_period\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\r\xc8\xde\x1f\x00\x98\xdf\x1f\x01\xa8\xe7\xb0*\x01\"\xb8\x01\n\tGroupInfo\x12\n\n\x02id\x18\x01 \x01(\x04\x12\'\n\x05\x61\x64min\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x10\n\x08metadata\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\x04\x12\x14\n\x0ctotal_weight\x18\x05 \x01(\t\x12=\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\r\xc8\xde\x1f\x00\x90\xdf\x1f\x01\xa8\xe7\xb0*\x01\"H\n\x0bGroupMember\x12\x10\n\x08group_id\x18\x01 \x01(\x04\x12\'\n\x06member\x18\x02 \x01(\x0b\x32\x17.cosmos.group.v1.Member\"\xb6\x02\n\x0fGroupPolicyInfo\x12)\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x10\n\x08group_id\x18\x02 \x01(\x04\x12\'\n\x05\x61\x64min\x18\x03 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x10\n\x08metadata\x18\x04 \x01(\t\x12\x0f\n\x07version\x18\x05 \x01(\x04\x12Q\n\x0f\x64\x65\x63ision_policy\x18\x06 \x01(\x0b\x32\x14.google.protobuf.AnyB\"\xca\xb4-\x1e\x63osmos.group.v1.DecisionPolicy\x12=\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\r\xc8\xde\x1f\x00\x90\xdf\x1f\x01\xa8\xe7\xb0*\x01:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x01\"\xce\x04\n\x08Proposal\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x36\n\x14group_policy_address\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x10\n\x08metadata\x18\x03 \x01(\t\x12+\n\tproposers\x18\x04 \x03(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12>\n\x0bsubmit_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\r\xc8\xde\x1f\x00\x90\xdf\x1f\x01\xa8\xe7\xb0*\x01\x12\x15\n\rgroup_version\x18\x06 \x01(\x04\x12\x1c\n\x14group_policy_version\x18\x07 \x01(\x04\x12/\n\x06status\x18\x08 \x01(\x0e\x32\x1f.cosmos.group.v1.ProposalStatus\x12\x43\n\x12\x66inal_tally_result\x18\t \x01(\x0b\x32\x1c.cosmos.group.v1.TallyResultB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12\x44\n\x11voting_period_end\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampB\r\xc8\xde\x1f\x00\x90\xdf\x1f\x01\xa8\xe7\xb0*\x01\x12@\n\x0f\x65xecutor_result\x18\x0b \x01(\x0e\x32\'.cosmos.group.v1.ProposalExecutorResult\x12&\n\x08messages\x18\x0c \x03(\x0b\x32\x14.google.protobuf.Any\x12\r\n\x05title\x18\r \x01(\t\x12\x0f\n\x07summary\x18\x0e \x01(\t:\x04\x88\xa0\x1f\x00\"k\n\x0bTallyResult\x12\x11\n\tyes_count\x18\x01 \x01(\t\x12\x15\n\rabstain_count\x18\x02 \x01(\t\x12\x10\n\x08no_count\x18\x03 \x01(\t\x12\x1a\n\x12no_with_veto_count\x18\x04 \x01(\t:\x04\x88\xa0\x1f\x00\"\xc3\x01\n\x04Vote\x12\x13\n\x0bproposal_id\x18\x01 \x01(\x04\x12\'\n\x05voter\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12+\n\x06option\x18\x03 \x01(\x0e\x32\x1b.cosmos.group.v1.VoteOption\x12\x10\n\x08metadata\x18\x04 \x01(\t\x12>\n\x0bsubmit_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\r\xc8\xde\x1f\x00\x90\xdf\x1f\x01\xa8\xe7\xb0*\x01*\x8f\x01\n\nVoteOption\x12\x1b\n\x17VOTE_OPTION_UNSPECIFIED\x10\x00\x12\x13\n\x0fVOTE_OPTION_YES\x10\x01\x12\x17\n\x13VOTE_OPTION_ABSTAIN\x10\x02\x12\x12\n\x0eVOTE_OPTION_NO\x10\x03\x12\x1c\n\x18VOTE_OPTION_NO_WITH_VETO\x10\x04\x1a\x04\x88\xa3\x1e\x00*\xce\x01\n\x0eProposalStatus\x12\x1f\n\x1bPROPOSAL_STATUS_UNSPECIFIED\x10\x00\x12\x1d\n\x19PROPOSAL_STATUS_SUBMITTED\x10\x01\x12\x1c\n\x18PROPOSAL_STATUS_ACCEPTED\x10\x02\x12\x1c\n\x18PROPOSAL_STATUS_REJECTED\x10\x03\x12\x1b\n\x17PROPOSAL_STATUS_ABORTED\x10\x04\x12\x1d\n\x19PROPOSAL_STATUS_WITHDRAWN\x10\x05\x1a\x04\x88\xa3\x1e\x00*\xba\x01\n\x16ProposalExecutorResult\x12(\n$PROPOSAL_EXECUTOR_RESULT_UNSPECIFIED\x10\x00\x12$\n PROPOSAL_EXECUTOR_RESULT_NOT_RUN\x10\x01\x12$\n PROPOSAL_EXECUTOR_RESULT_SUCCESS\x10\x02\x12$\n PROPOSAL_EXECUTOR_RESULT_FAILURE\x10\x03\x1a\x04\x88\xa3\x1e\x00\x42&Z$github.com/cosmos/cosmos-sdk/x/groupb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.group.v1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z$github.com/cosmos/cosmos-sdk/x/group'
  _globals['_VOTEOPTION']._loaded_options = None
  _globals['_VOTEOPTION']._serialized_options = b'\210\243\036\000'
  _globals['_PROPOSALSTATUS']._loaded_options = None
  _globals['_PROPOSALSTATUS']._serialized_options = b'\210\243\036\000'
  _globals['_PROPOSALEXECUTORRESULT']._loaded_options = None
  _globals['_PROPOSALEXECUTORRESULT']._serialized_options = b'\210\243\036\000'
  _globals['_MEMBER'].fields_by_name['address']._loaded_options = None
  _globals['_MEMBER'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MEMBER'].fields_by_name['added_at']._loaded_options = None
  _globals['_MEMBER'].fields_by_name['added_at']._serialized_options = b'\310\336\037\000\220\337\037\001\250\347\260*\001'
  _globals['_MEMBERREQUEST'].fields_by_name['address']._loaded_options = None
  _globals['_MEMBERREQUEST'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_THRESHOLDDECISIONPOLICY']._loaded_options = None
  _globals['_THRESHOLDDECISIONPOLICY']._serialized_options = b'\312\264-\036cosmos.group.v1.DecisionPolicy\212\347\260*\"cosmos-sdk/ThresholdDecisionPolicy'
  _globals['_PERCENTAGEDECISIONPOLICY']._loaded_options = None
  _globals['_PERCENTAGEDECISIONPOLICY']._serialized_options = b'\312\264-\036cosmos.group.v1.DecisionPolicy\212\347\260*#cosmos-sdk/PercentageDecisionPolicy'
  _globals['_DECISIONPOLICYWINDOWS'].fields_by_name['voting_period']._loaded_options = None
  _globals['_DECISIONPOLICYWINDOWS'].fields_by_name['voting_period']._serialized_options = b'\310\336\037\000\230\337\037\001\250\347\260*\001'
  _globals['_DECISIONPOLICYWINDOWS'].fields_by_name['min_execution_period']._loaded_options = None
  _globals['_DECISIONPOLICYWINDOWS'].fields_by_name['min_execution_period']._serialized_options = b'\310\336\037\000\230\337\037\001\250\347\260*\001'
  _globals['_GROUPINFO'].fields_by_name['admin']._loaded_options = None
  _globals['_GROUPINFO'].fields_by_name['admin']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_GROUPINFO'].fields_by_name['created_at']._loaded_options = None
  _globals['_GROUPINFO'].fields_by_name['created_at']._serialized_options = b'\310\336\037\000\220\337\037\001\250\347\260*\001'
  _globals['_GROUPPOLICYINFO'].fields_by_name['address']._loaded_options = None
  _globals['_GROUPPOLICYINFO'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_GROUPPOLICYINFO'].fields_by_name['admin']._loaded_options = None
  _globals['_GROUPPOLICYINFO'].fields_by_name['admin']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_GROUPPOLICYINFO'].fields_by_name['decision_policy']._loaded_options = None
  _globals['_GROUPPOLICYINFO'].fields_by_name['decision_policy']._serialized_options = b'\312\264-\036cosmos.group.v1.DecisionPolicy'
  _globals['_GROUPPOLICYINFO'].fields_by_name['created_at']._loaded_options = None
  _globals['_GROUPPOLICYINFO'].fields_by_name['created_at']._serialized_options = b'\310\336\037\000\220\337\037\001\250\347\260*\001'
  _globals['_GROUPPOLICYINFO']._loaded_options = None
  _globals['_GROUPPOLICYINFO']._serialized_options = b'\210\240\037\000\350\240\037\001'
  _globals['_PROPOSAL'].fields_by_name['group_policy_address']._loaded_options = None
  _globals['_PROPOSAL'].fields_by_name['group_policy_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_PROPOSAL'].fields_by_name['proposers']._loaded_options = None
  _globals['_PROPOSAL'].fields_by_name['proposers']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_PROPOSAL'].fields_by_name['submit_time']._loaded_options = None
  _globals['_PROPOSAL'].fields_by_name['submit_time']._serialized_options = b'\310\336\037\000\220\337\037\001\250\347\260*\001'
  _globals['_PROPOSAL'].fields_by_name['final_tally_result']._loaded_options = None
  _globals['_PROPOSAL'].fields_by_name['final_tally_result']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_PROPOSAL'].fields_by_name['voting_period_end']._loaded_options = None
  _globals['_PROPOSAL'].fields_by_name['voting_period_end']._serialized_options = b'\310\336\037\000\220\337\037\001\250\347\260*\001'
  _globals['_PROPOSAL']._loaded_options = None
  _globals['_PROPOSAL']._serialized_options = b'\210\240\037\000'
  _globals['_TALLYRESULT']._loaded_options = None
  _globals['_TALLYRESULT']._serialized_options = b'\210\240\037\000'
  _globals['_VOTE'].fields_by_name['voter']._loaded_options = None
  _globals['_VOTE'].fields_by_name['voter']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_VOTE'].fields_by_name['submit_time']._loaded_options = None
  _globals['_VOTE'].fields_by_name['submit_time']._serialized_options = b'\310\336\037\000\220\337\037\001\250\347\260*\001'
  _globals['_VOTEOPTION']._serialized_start=2450
  _globals['_VOTEOPTION']._serialized_end=2593
  _globals['_PROPOSALSTATUS']._serialized_start=2596
  _globals['_PROPOSALSTATUS']._serialized_end=2802
  _globals['_PROPOSALEXECUTORRESULT']._serialized_start=2805
  _globals['_PROPOSALEXECUTORRESULT']._serialized_end=2991
  _globals['_MEMBER']._serialized_start=209
  _globals['_MEMBER']._serialized_end=355
  _globals['_MEMBERREQUEST']._serialized_start=357
  _globals['_MEMBERREQUEST']._serialized_end=449
  _globals['_THRESHOLDDECISIONPOLICY']._serialized_start=452
  _globals['_THRESHOLDDECISIONPOLICY']._serialized_end=628
  _globals['_PERCENTAGEDECISIONPOLICY']._serialized_start=631
  _globals['_PERCENTAGEDECISIONPOLICY']._serialized_end=810
  _globals['_DECISIONPOLICYWINDOWS']._serialized_start=813
  _globals['_DECISIONPOLICYWINDOWS']._serialized_end=973
  _globals['_GROUPINFO']._serialized_start=976
  _globals['_GROUPINFO']._serialized_end=1160
  _globals['_GROUPMEMBER']._serialized_start=1162
  _globals['_GROUPMEMBER']._serialized_end=1234
  _globals['_GROUPPOLICYINFO']._serialized_start=1237
  _globals['_GROUPPOLICYINFO']._serialized_end=1547
  _globals['_PROPOSAL']._serialized_start=1550
  _globals['_PROPOSAL']._serialized_end=2140
  _globals['_TALLYRESULT']._serialized_start=2142
  _globals['_TALLYRESULT']._serialized_end=2249
  _globals['_VOTE']._serialized_start=2252
  _globals['_VOTE']._serialized_end=2447
# @@protoc_insertion_point(module_scope)



from v4_proto.cosmos.msg.v1 import msg_pb2 as _msg_pb2
from v4_proto.dydxprotocol.ratelimit import limit_params_pb2 as _limit_params_pb2
from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MsgSetLimitParams(_message.Message):
    __slots__ = ("authority", "limit_params")
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    LIMIT_PARAMS_FIELD_NUMBER: _ClassVar[int]
    authority: str
    limit_params: _limit_params_pb2.LimitParams
    def __init__(self, authority: _Optional[str] = ..., limit_params: _Optional[_Union[_limit_params_pb2.LimitParams, _Mapping]] = ...) -> None: ...

class MsgSetLimitParamsResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import any_pb2 as _any_pb2
from v4_proto.cosmos.authz.v1beta1 import authz_pb2 as _authz_pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as _msg_pb2
from v4_proto.amino import amino_pb2 as _amino_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MsgGrant(_message.Message):
    __slots__ = ("granter", "grantee", "grant")
    GRANTER_FIELD_NUMBER: _ClassVar[int]
    GRANTEE_FIELD_NUMBER: _ClassVar[int]
    GRANT_FIELD_NUMBER: _ClassVar[int]
    granter: str
    grantee: str
    grant: _authz_pb2.Grant
    def __init__(self, granter: _Optional[str] = ..., grantee: _Optional[str] = ..., grant: _Optional[_Union[_authz_pb2.Grant, _Mapping]] = ...) -> None: ...

class MsgGrantResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgExec(_message.Message):
    __slots__ = ("grantee", "msgs")
    GRANTEE_FIELD_NUMBER: _ClassVar[int]
    MSGS_FIELD_NUMBER: _ClassVar[int]
    grantee: str
    msgs: _containers.RepeatedCompositeFieldContainer[_any_pb2.Any]
    def __init__(self, grantee: _Optional[str] = ..., msgs: _Optional[_Iterable[_Union[_any_pb2.Any, _Mapping]]] = ...) -> None: ...

class MsgExecResponse(_message.Message):
    __slots__ = ("results",)
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    results: _containers.RepeatedScalarFieldContainer[bytes]
    def __init__(self, results: _Optional[_Iterable[bytes]] = ...) -> None: ...

class MsgRevoke(_message.Message):
    __slots__ = ("granter", "grantee", "msg_type_url")
    GRANTER_FIELD_NUMBER: _ClassVar[int]
    GRANTEE_FIELD_NUMBER: _ClassVar[int]
    MSG_TYPE_URL_FIELD_NUMBER: _ClassVar[int]
    granter: str
    grantee: str
    msg_type_url: str
    def __init__(self, granter: _Optional[str] = ..., grantee: _Optional[str] = ..., msg_type_url: _Optional[str] = ...) -> None: ...

class MsgRevokeResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.dydxprotocol.accountplus import accountplus_pb2 as _accountplus_pb2
from v4_proto.dydxprotocol.accountplus import models_pb2 as _models_pb2
from v4_proto.dydxprotocol.accountplus import params_pb2 as _params_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AuthenticatorData(_message.Message):
    __slots__ = ("address", "authenticators")
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    AUTHENTICATORS_FIELD_NUMBER: _ClassVar[int]
    address: str
    authenticators: _containers.RepeatedCompositeFieldContainer[_models_pb2.AccountAuthenticator]
    def __init__(self, address: _Optional[str] = ..., authenticators: _Optional[_Iterable[_Union[_models_pb2.AccountAuthenticator, _Mapping]]] = ...) -> None: ...

class GenesisState(_message.Message):
    __slots__ = ("accounts", "params", "next_authenticator_id", "authenticator_data")
    ACCOUNTS_FIELD_NUMBER: _ClassVar[int]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    NEXT_AUTHENTICATOR_ID_FIELD_NUMBER: _ClassVar[int]
    AUTHENTICATOR_DATA_FIELD_NUMBER: _ClassVar[int]
    accounts: _containers.RepeatedCompositeFieldContainer[_accountplus_pb2.AccountState]
    params: _params_pb2.Params
    next_authenticator_id: int
    authenticator_data: _containers.RepeatedCompositeFieldContainer[AuthenticatorData]
    def __init__(self, accounts: _Optional[_Iterable[_Union[_accountplus_pb2.AccountState, _Mapping]]] = ..., params: _Optional[_Union[_params_pb2.Params, _Mapping]] = ..., next_authenticator_id: _Optional[int] = ..., authenticator_data: _Optional[_Iterable[_Union[AuthenticatorData, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/sending/tx.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/sending/tx.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.dydxprotocol.sending import transfer_pb2 as dydxprotocol_dot_sending_dot_transfer__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x64ydxprotocol/sending/tx.proto\x12\x14\x64ydxprotocol.sending\x1a#dydxprotocol/sending/transfer.proto\"E\n\x11MsgCreateTransfer\x12\x30\n\x08transfer\x18\x01 \x01(\x0b\x32\x1e.dydxprotocol.sending.Transfer\"\x1b\n\x19MsgCreateTransferResponse\" \n\x1eMsgDepositToSubaccountResponse\"#\n!MsgWithdrawFromSubaccountResponse\"$\n\"MsgSendFromModuleToAccountResponse2\xf9\x03\n\x03Msg\x12j\n\x0e\x43reateTransfer\x12\'.dydxprotocol.sending.MsgCreateTransfer\x1a/.dydxprotocol.sending.MsgCreateTransferResponse\x12y\n\x13\x44\x65positToSubaccount\x12,.dydxprotocol.sending.MsgDepositToSubaccount\x1a\x34.dydxprotocol.sending.MsgDepositToSubaccountResponse\x12\x82\x01\n\x16WithdrawFromSubaccount\x12/.dydxprotocol.sending.MsgWithdrawFromSubaccount\x1a\x37.dydxprotocol.sending.MsgWithdrawFromSubaccountResponse\x12\x85\x01\n\x17SendFromModuleToAccount\x12\x30.dydxprotocol.sending.MsgSendFromModuleToAccount\x1a\x38.dydxprotocol.sending.MsgSendFromModuleToAccountResponseB;Z9github.com/dydxprotocol/v4-chain/protocol/x/sending/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.sending.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z9github.com/dydxprotocol/v4-chain/protocol/x/sending/types'
  _globals['_MSGCREATETRANSFER']._serialized_start=92
  _globals['_MSGCREATETRANSFER']._serialized_end=161
  _globals['_MSGCREATETRANSFERRESPONSE']._serialized_start=163
  _globals['_MSGCREATETRANSFERRESPONSE']._serialized_end=190
  _globals['_MSGDEPOSITTOSUBACCOUNTRESPONSE']._serialized_start=192
  _globals['_MSGDEPOSITTOSUBACCOUNTRESPONSE']._serialized_end=224
  _globals['_MSGWITHDRAWFROMSUBACCOUNTRESPONSE']._serialized_start=226
  _globals['_MSGWITHDRAWFROMSUBACCOUNTRESPONSE']._serialized_end=261
  _globals['_MSGSENDFROMMODULETOACCOUNTRESPONSE']._serialized_start=263
  _globals['_MSGSENDFROMMODULETOACCOUNTRESPONSE']._serialized_end=299
  _globals['_MSG']._serialized_start=302
  _globals['_MSG']._serialized_end=807
# @@protoc_insertion_point(module_scope)



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class MultiSignature(_message.Message):
    __slots__ = ("signatures",)
    SIGNATURES_FIELD_NUMBER: _ClassVar[int]
    signatures: _containers.RepeatedScalarFieldContainer[bytes]
    def __init__(self, signatures: _Optional[_Iterable[bytes]] = ...) -> None: ...

class CompactBitArray(_message.Message):
    __slots__ = ("extra_bits_stored", "elems")
    EXTRA_BITS_STORED_FIELD_NUMBER: _ClassVar[int]
    ELEMS_FIELD_NUMBER: _ClassVar[int]
    extra_bits_stored: int
    elems: bytes
    def __init__(self, extra_bits_stored: _Optional[int] = ..., elems: _Optional[bytes] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class PendingSendPacket(_message.Message):
    __slots__ = ("channel_id", "sequence")
    CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    channel_id: str
    sequence: int
    def __init__(self, channel_id: _Optional[str] = ..., sequence: _Optional[int] = ...) -> None: ...



from v4_proto.cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from v4_proto.google.api import annotations_pb2 as _annotations_pb2
from v4_proto.cosmos.nft.v1beta1 import nft_pb2 as _nft_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryBalanceRequest(_message.Message):
    __slots__ = ("class_id", "owner")
    CLASS_ID_FIELD_NUMBER: _ClassVar[int]
    OWNER_FIELD_NUMBER: _ClassVar[int]
    class_id: str
    owner: str
    def __init__(self, class_id: _Optional[str] = ..., owner: _Optional[str] = ...) -> None: ...

class QueryBalanceResponse(_message.Message):
    __slots__ = ("amount",)
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    amount: int
    def __init__(self, amount: _Optional[int] = ...) -> None: ...

class QueryOwnerRequest(_message.Message):
    __slots__ = ("class_id", "id")
    CLASS_ID_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    class_id: str
    id: str
    def __init__(self, class_id: _Optional[str] = ..., id: _Optional[str] = ...) -> None: ...

class QueryOwnerResponse(_message.Message):
    __slots__ = ("owner",)
    OWNER_FIELD_NUMBER: _ClassVar[int]
    owner: str
    def __init__(self, owner: _Optional[str] = ...) -> None: ...

class QuerySupplyRequest(_message.Message):
    __slots__ = ("class_id",)
    CLASS_ID_FIELD_NUMBER: _ClassVar[int]
    class_id: str
    def __init__(self, class_id: _Optional[str] = ...) -> None: ...

class QuerySupplyResponse(_message.Message):
    __slots__ = ("amount",)
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    amount: int
    def __init__(self, amount: _Optional[int] = ...) -> None: ...

class QueryNFTsRequest(_message.Message):
    __slots__ = ("class_id", "owner", "pagination")
    CLASS_ID_FIELD_NUMBER: _ClassVar[int]
    OWNER_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    class_id: str
    owner: str
    pagination: _pagination_pb2.PageRequest
    def __init__(self, class_id: _Optional[str] = ..., owner: _Optional[str] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryNFTsResponse(_message.Message):
    __slots__ = ("nfts", "pagination")
    NFTS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    nfts: _containers.RepeatedCompositeFieldContainer[_nft_pb2.NFT]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, nfts: _Optional[_Iterable[_Union[_nft_pb2.NFT, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryNFTRequest(_message.Message):
    __slots__ = ("class_id", "id")
    CLASS_ID_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    class_id: str
    id: str
    def __init__(self, class_id: _Optional[str] = ..., id: _Optional[str] = ...) -> None: ...

class QueryNFTResponse(_message.Message):
    __slots__ = ("nft",)
    NFT_FIELD_NUMBER: _ClassVar[int]
    nft: _nft_pb2.NFT
    def __init__(self, nft: _Optional[_Union[_nft_pb2.NFT, _Mapping]] = ...) -> None: ...

class QueryClassRequest(_message.Message):
    __slots__ = ("class_id",)
    CLASS_ID_FIELD_NUMBER: _ClassVar[int]
    class_id: str
    def __init__(self, class_id: _Optional[str] = ...) -> None: ...

class QueryClassResponse(_message.Message):
    __slots__ = ()
    CLASS_FIELD_NUMBER: _ClassVar[int]
    def __init__(self, **kwargs) -> None: ...

class QueryClassesRequest(_message.Message):
    __slots__ = ("pagination",)
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest
    def __init__(self, pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryClassesResponse(_message.Message):
    __slots__ = ("classes", "pagination")
    CLASSES_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    classes: _containers.RepeatedCompositeFieldContainer[_nft_pb2.Class]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, classes: _Optional[_Iterable[_Union[_nft_pb2.Class, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from v4_proto.cosmos.group.v1 import query_pb2 as cosmos_dot_group_dot_v1_dot_query__pb2

GRPC_GENERATED_VERSION = '1.75.1'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in cosmos/group/v1/query_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class QueryStub(object):
    """Query is the cosmos.group.v1 Query service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GroupInfo = channel.unary_unary(
                '/cosmos.group.v1.Query/GroupInfo',
                request_serializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryGroupInfoRequest.SerializeToString,
                response_deserializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryGroupInfoResponse.FromString,
                _registered_method=True)
        self.GroupPolicyInfo = channel.unary_unary(
                '/cosmos.group.v1.Query/GroupPolicyInfo',
                request_serializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryGroupPolicyInfoRequest.SerializeToString,
                response_deserializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryGroupPolicyInfoResponse.FromString,
                _registered_method=True)
        self.GroupMembers = channel.unary_unary(
                '/cosmos.group.v1.Query/GroupMembers',
                request_serializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryGroupMembersRequest.SerializeToString,
                response_deserializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryGroupMembersResponse.FromString,
                _registered_method=True)
        self.GroupsByAdmin = channel.unary_unary(
                '/cosmos.group.v1.Query/GroupsByAdmin',
                request_serializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryGroupsByAdminRequest.SerializeToString,
                response_deserializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryGroupsByAdminResponse.FromString,
                _registered_method=True)
        self.GroupPoliciesByGroup = channel.unary_unary(
                '/cosmos.group.v1.Query/GroupPoliciesByGroup',
                request_serializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryGroupPoliciesByGroupRequest.SerializeToString,
                response_deserializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryGroupPoliciesByGroupResponse.FromString,
                _registered_method=True)
        self.GroupPoliciesByAdmin = channel.unary_unary(
                '/cosmos.group.v1.Query/GroupPoliciesByAdmin',
                request_serializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryGroupPoliciesByAdminRequest.SerializeToString,
                response_deserializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryGroupPoliciesByAdminResponse.FromString,
                _registered_method=True)
        self.Proposal = channel.unary_unary(
                '/cosmos.group.v1.Query/Proposal',
                request_serializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryProposalRequest.SerializeToString,
                response_deserializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryProposalResponse.FromString,
                _registered_method=True)
        self.ProposalsByGroupPolicy = channel.unary_unary(
                '/cosmos.group.v1.Query/ProposalsByGroupPolicy',
                request_serializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryProposalsByGroupPolicyRequest.SerializeToString,
                response_deserializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryProposalsByGroupPolicyResponse.FromString,
                _registered_method=True)
        self.VoteByProposalVoter = channel.unary_unary(
                '/cosmos.group.v1.Query/VoteByProposalVoter',
                request_serializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryVoteByProposalVoterRequest.SerializeToString,
                response_deserializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryVoteByProposalVoterResponse.FromString,
                _registered_method=True)
        self.VotesByProposal = channel.unary_unary(
                '/cosmos.group.v1.Query/VotesByProposal',
                request_serializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryVotesByProposalRequest.SerializeToString,
                response_deserializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryVotesByProposalResponse.FromString,
                _registered_method=True)
        self.VotesByVoter = channel.unary_unary(
                '/cosmos.group.v1.Query/VotesByVoter',
                request_serializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryVotesByVoterRequest.SerializeToString,
                response_deserializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryVotesByVoterResponse.FromString,
                _registered_method=True)
        self.GroupsByMember = channel.unary_unary(
                '/cosmos.group.v1.Query/GroupsByMember',
                request_serializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryGroupsByMemberRequest.SerializeToString,
                response_deserializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryGroupsByMemberResponse.FromString,
                _registered_method=True)
        self.TallyResult = channel.unary_unary(
                '/cosmos.group.v1.Query/TallyResult',
                request_serializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryTallyResultRequest.SerializeToString,
                response_deserializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryTallyResultResponse.FromString,
                _registered_method=True)
        self.Groups = channel.unary_unary(
                '/cosmos.group.v1.Query/Groups',
                request_serializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryGroupsRequest.SerializeToString,
                response_deserializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryGroupsResponse.FromString,
                _registered_method=True)


class QueryServicer(object):
    """Query is the cosmos.group.v1 Query service.
    """

    def GroupInfo(self, request, context):
        """GroupInfo queries group info based on group id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GroupPolicyInfo(self, request, context):
        """GroupPolicyInfo queries group policy info based on account address of group policy.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GroupMembers(self, request, context):
        """GroupMembers queries members of a group by group id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GroupsByAdmin(self, request, context):
        """GroupsByAdmin queries groups by admin address.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GroupPoliciesByGroup(self, request, context):
        """GroupPoliciesByGroup queries group policies by group id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GroupPoliciesByAdmin(self, request, context):
        """GroupPoliciesByAdmin queries group policies by admin address.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Proposal(self, request, context):
        """Proposal queries a proposal based on proposal id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ProposalsByGroupPolicy(self, request, context):
        """ProposalsByGroupPolicy queries proposals based on account address of group policy.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def VoteByProposalVoter(self, request, context):
        """VoteByProposalVoter queries a vote by proposal id and voter.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def VotesByProposal(self, request, context):
        """VotesByProposal queries a vote by proposal id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def VotesByVoter(self, request, context):
        """VotesByVoter queries a vote by voter.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GroupsByMember(self, request, context):
        """GroupsByMember queries groups by member address.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TallyResult(self, request, context):
        """TallyResult returns the tally result of a proposal. If the proposal is
        still in voting period, then this query computes the current tally state,
        which might not be final. On the other hand, if the proposal is final,
        then it simply returns the `final_tally_result` state stored in the
        proposal itself.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Groups(self, request, context):
        """Groups queries all groups in state.

        Since: cosmos-sdk 0.47.1
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GroupInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GroupInfo,
                    request_deserializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryGroupInfoRequest.FromString,
                    response_serializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryGroupInfoResponse.SerializeToString,
            ),
            'GroupPolicyInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GroupPolicyInfo,
                    request_deserializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryGroupPolicyInfoRequest.FromString,
                    response_serializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryGroupPolicyInfoResponse.SerializeToString,
            ),
            'GroupMembers': grpc.unary_unary_rpc_method_handler(
                    servicer.GroupMembers,
                    request_deserializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryGroupMembersRequest.FromString,
                    response_serializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryGroupMembersResponse.SerializeToString,
            ),
            'GroupsByAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.GroupsByAdmin,
                    request_deserializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryGroupsByAdminRequest.FromString,
                    response_serializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryGroupsByAdminResponse.SerializeToString,
            ),
            'GroupPoliciesByGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.GroupPoliciesByGroup,
                    request_deserializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryGroupPoliciesByGroupRequest.FromString,
                    response_serializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryGroupPoliciesByGroupResponse.SerializeToString,
            ),
            'GroupPoliciesByAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.GroupPoliciesByAdmin,
                    request_deserializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryGroupPoliciesByAdminRequest.FromString,
                    response_serializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryGroupPoliciesByAdminResponse.SerializeToString,
            ),
            'Proposal': grpc.unary_unary_rpc_method_handler(
                    servicer.Proposal,
                    request_deserializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryProposalRequest.FromString,
                    response_serializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryProposalResponse.SerializeToString,
            ),
            'ProposalsByGroupPolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.ProposalsByGroupPolicy,
                    request_deserializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryProposalsByGroupPolicyRequest.FromString,
                    response_serializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryProposalsByGroupPolicyResponse.SerializeToString,
            ),
            'VoteByProposalVoter': grpc.unary_unary_rpc_method_handler(
                    servicer.VoteByProposalVoter,
                    request_deserializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryVoteByProposalVoterRequest.FromString,
                    response_serializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryVoteByProposalVoterResponse.SerializeToString,
            ),
            'VotesByProposal': grpc.unary_unary_rpc_method_handler(
                    servicer.VotesByProposal,
                    request_deserializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryVotesByProposalRequest.FromString,
                    response_serializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryVotesByProposalResponse.SerializeToString,
            ),
            'VotesByVoter': grpc.unary_unary_rpc_method_handler(
                    servicer.VotesByVoter,
                    request_deserializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryVotesByVoterRequest.FromString,
                    response_serializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryVotesByVoterResponse.SerializeToString,
            ),
            'GroupsByMember': grpc.unary_unary_rpc_method_handler(
                    servicer.GroupsByMember,
                    request_deserializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryGroupsByMemberRequest.FromString,
                    response_serializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryGroupsByMemberResponse.SerializeToString,
            ),
            'TallyResult': grpc.unary_unary_rpc_method_handler(
                    servicer.TallyResult,
                    request_deserializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryTallyResultRequest.FromString,
                    response_serializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryTallyResultResponse.SerializeToString,
            ),
            'Groups': grpc.unary_unary_rpc_method_handler(
                    servicer.Groups,
                    request_deserializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryGroupsRequest.FromString,
                    response_serializer=cosmos_dot_group_dot_v1_dot_query__pb2.QueryGroupsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'cosmos.group.v1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('cosmos.group.v1.Query', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query is the cosmos.group.v1 Query service.
    """

    @staticmethod
    def GroupInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.group.v1.Query/GroupInfo',
            cosmos_dot_group_dot_v1_dot_query__pb2.QueryGroupInfoRequest.SerializeToString,
            cosmos_dot_group_dot_v1_dot_query__pb2.QueryGroupInfoResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GroupPolicyInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.group.v1.Query/GroupPolicyInfo',
            cosmos_dot_group_dot_v1_dot_query__pb2.QueryGroupPolicyInfoRequest.SerializeToString,
            cosmos_dot_group_dot_v1_dot_query__pb2.QueryGroupPolicyInfoResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GroupMembers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.group.v1.Query/GroupMembers',
            cosmos_dot_group_dot_v1_dot_query__pb2.QueryGroupMembersRequest.SerializeToString,
            cosmos_dot_group_dot_v1_dot_query__pb2.QueryGroupMembersResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GroupsByAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.group.v1.Query/GroupsByAdmin',
            cosmos_dot_group_dot_v1_dot_query__pb2.QueryGroupsByAdminRequest.SerializeToString,
            cosmos_dot_group_dot_v1_dot_query__pb2.QueryGroupsByAdminResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GroupPoliciesByGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.group.v1.Query/GroupPoliciesByGroup',
            cosmos_dot_group_dot_v1_dot_query__pb2.QueryGroupPoliciesByGroupRequest.SerializeToString,
            cosmos_dot_group_dot_v1_dot_query__pb2.QueryGroupPoliciesByGroupResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GroupPoliciesByAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.group.v1.Query/GroupPoliciesByAdmin',
            cosmos_dot_group_dot_v1_dot_query__pb2.QueryGroupPoliciesByAdminRequest.SerializeToString,
            cosmos_dot_group_dot_v1_dot_query__pb2.QueryGroupPoliciesByAdminResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Proposal(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.group.v1.Query/Proposal',
            cosmos_dot_group_dot_v1_dot_query__pb2.QueryProposalRequest.SerializeToString,
            cosmos_dot_group_dot_v1_dot_query__pb2.QueryProposalResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ProposalsByGroupPolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.group.v1.Query/ProposalsByGroupPolicy',
            cosmos_dot_group_dot_v1_dot_query__pb2.QueryProposalsByGroupPolicyRequest.SerializeToString,
            cosmos_dot_group_dot_v1_dot_query__pb2.QueryProposalsByGroupPolicyResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def VoteByProposalVoter(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.group.v1.Query/VoteByProposalVoter',
            cosmos_dot_group_dot_v1_dot_query__pb2.QueryVoteByProposalVoterRequest.SerializeToString,
            cosmos_dot_group_dot_v1_dot_query__pb2.QueryVoteByProposalVoterResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def VotesByProposal(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.group.v1.Query/VotesByProposal',
            cosmos_dot_group_dot_v1_dot_query__pb2.QueryVotesByProposalRequest.SerializeToString,
            cosmos_dot_group_dot_v1_dot_query__pb2.QueryVotesByProposalResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def VotesByVoter(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.group.v1.Query/VotesByVoter',
            cosmos_dot_group_dot_v1_dot_query__pb2.QueryVotesByVoterRequest.SerializeToString,
            cosmos_dot_group_dot_v1_dot_query__pb2.QueryVotesByVoterResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GroupsByMember(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.group.v1.Query/GroupsByMember',
            cosmos_dot_group_dot_v1_dot_query__pb2.QueryGroupsByMemberRequest.SerializeToString,
            cosmos_dot_group_dot_v1_dot_query__pb2.QueryGroupsByMemberResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def TallyResult(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.group.v1.Query/TallyResult',
            cosmos_dot_group_dot_v1_dot_query__pb2.QueryTallyResultRequest.SerializeToString,
            cosmos_dot_group_dot_v1_dot_query__pb2.QueryTallyResultResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Groups(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.group.v1.Query/Groups',
            cosmos_dot_group_dot_v1_dot_query__pb2.QueryGroupsRequest.SerializeToString,
            cosmos_dot_group_dot_v1_dot_query__pb2.QueryGroupsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/vault/share.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/vault/share.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x64ydxprotocol/vault/share.proto\x12\x12\x64ydxprotocol.vault\x1a\x14gogoproto/gogo.proto\x1a\x19\x63osmos_proto/cosmos.proto\"i\n\tNumShares\x12\\\n\nnum_shares\x18\x02 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\"j\n\nOwnerShare\x12\'\n\x05owner\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x33\n\x06shares\x18\x02 \x01(\x0b\x32\x1d.dydxprotocol.vault.NumSharesB\x04\xc8\xde\x1f\x00\"h\n\x11OwnerShareUnlocks\x12\x15\n\rowner_address\x18\x01 \x01(\t\x12<\n\rshare_unlocks\x18\x02 \x03(\x0b\x32\x1f.dydxprotocol.vault.ShareUnlockB\x04\xc8\xde\x1f\x00\"_\n\x0bShareUnlock\x12\x33\n\x06shares\x18\x01 \x01(\x0b\x32\x1d.dydxprotocol.vault.NumSharesB\x04\xc8\xde\x1f\x00\x12\x1b\n\x13unlock_block_height\x18\x02 \x01(\rB9Z7github.com/dydxprotocol/v4-chain/protocol/x/vault/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.vault.share_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/dydxprotocol/v4-chain/protocol/x/vault/types'
  _globals['_NUMSHARES'].fields_by_name['num_shares']._loaded_options = None
  _globals['_NUMSHARES'].fields_by_name['num_shares']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_OWNERSHARE'].fields_by_name['owner']._loaded_options = None
  _globals['_OWNERSHARE'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_OWNERSHARE'].fields_by_name['shares']._loaded_options = None
  _globals['_OWNERSHARE'].fields_by_name['shares']._serialized_options = b'\310\336\037\000'
  _globals['_OWNERSHAREUNLOCKS'].fields_by_name['share_unlocks']._loaded_options = None
  _globals['_OWNERSHAREUNLOCKS'].fields_by_name['share_unlocks']._serialized_options = b'\310\336\037\000'
  _globals['_SHAREUNLOCK'].fields_by_name['shares']._loaded_options = None
  _globals['_SHAREUNLOCK'].fields_by_name['shares']._serialized_options = b'\310\336\037\000'
  _globals['_NUMSHARES']._serialized_start=103
  _globals['_NUMSHARES']._serialized_end=208
  _globals['_OWNERSHARE']._serialized_start=210
  _globals['_OWNERSHARE']._serialized_end=316
  _globals['_OWNERSHAREUNLOCKS']._serialized_start=318
  _globals['_OWNERSHAREUNLOCKS']._serialized_end=422
  _globals['_SHAREUNLOCK']._serialized_start=424
  _globals['_SHAREUNLOCK']._serialized_end=519
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/daemons/pricefeed/price_feed.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/daemons/pricefeed/price_feed.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/dydxprotocol/daemons/pricefeed/price_feed.proto\x12\x1e\x64ydxprotocol.daemons.pricefeed\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"l\n\x19UpdateMarketPricesRequest\x12O\n\x14market_price_updates\x18\x01 \x03(\x0b\x32\x31.dydxprotocol.daemons.pricefeed.MarketPriceUpdate\"\x1c\n\x1aUpdateMarketPricesResponse\"s\n\rExchangePrice\x12\x13\n\x0b\x65xchange_id\x18\x01 \x01(\t\x12\r\n\x05price\x18\x02 \x01(\x04\x12>\n\x10last_update_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x01\x90\xdf\x1f\x01\"n\n\x11MarketPriceUpdate\x12\x11\n\tmarket_id\x18\x01 \x01(\r\x12\x46\n\x0f\x65xchange_prices\x18\x02 \x03(\x0b\x32-.dydxprotocol.daemons.pricefeed.ExchangePrice2\xa2\x01\n\x10PriceFeedService\x12\x8d\x01\n\x12UpdateMarketPrices\x12\x39.dydxprotocol.daemons.pricefeed.UpdateMarketPricesRequest\x1a:.dydxprotocol.daemons.pricefeed.UpdateMarketPricesResponse\"\x00\x42\x41Z?github.com/dydxprotocol/v4-chain/protocol/daemons/pricefeed/apib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.daemons.pricefeed.price_feed_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z?github.com/dydxprotocol/v4-chain/protocol/daemons/pricefeed/api'
  _globals['_EXCHANGEPRICE'].fields_by_name['last_update_time']._loaded_options = None
  _globals['_EXCHANGEPRICE'].fields_by_name['last_update_time']._serialized_options = b'\310\336\037\001\220\337\037\001'
  _globals['_UPDATEMARKETPRICESREQUEST']._serialized_start=138
  _globals['_UPDATEMARKETPRICESREQUEST']._serialized_end=246
  _globals['_UPDATEMARKETPRICESRESPONSE']._serialized_start=248
  _globals['_UPDATEMARKETPRICESRESPONSE']._serialized_end=276
  _globals['_EXCHANGEPRICE']._serialized_start=278
  _globals['_EXCHANGEPRICE']._serialized_end=393
  _globals['_MARKETPRICEUPDATE']._serialized_start=395
  _globals['_MARKETPRICEUPDATE']._serialized_end=505
  _globals['_PRICEFEEDSERVICE']._serialized_start=508
  _globals['_PRICEFEEDSERVICE']._serialized_end=670
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/base/tendermint/v1beta1/types.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cosmos/base/tendermint/v1beta1/types.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.tendermint.types import types_pb2 as tendermint_dot_types_dot_types__pb2
from v4_proto.tendermint.types import evidence_pb2 as tendermint_dot_types_dot_evidence__pb2
from v4_proto.tendermint.version import types_pb2 as tendermint_dot_version_dot_types__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from v4_proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*cosmos/base/tendermint/v1beta1/types.proto\x12\x1e\x63osmos.base.tendermint.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1ctendermint/types/types.proto\x1a\x1ftendermint/types/evidence.proto\x1a\x1etendermint/version/types.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x11\x61mino/amino.proto\"\xe7\x01\n\x05\x42lock\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32&.cosmos.base.tendermint.v1beta1.HeaderB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12/\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x16.tendermint.types.DataB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12;\n\x08\x65vidence\x18\x03 \x01(\x0b\x32\x1e.tendermint.types.EvidenceListB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12-\n\x0blast_commit\x18\x04 \x01(\x0b\x32\x18.tendermint.types.Commit\"\xc2\x03\n\x06Header\x12\x39\n\x07version\x18\x01 \x01(\x0b\x32\x1d.tendermint.version.ConsensusB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12\x1d\n\x08\x63hain_id\x18\x02 \x01(\tB\x0b\xe2\xde\x1f\x07\x43hainID\x12\x0e\n\x06height\x18\x03 \x01(\x03\x12\x37\n\x04time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\r\xc8\xde\x1f\x00\x90\xdf\x1f\x01\xa8\xe7\xb0*\x01\x12;\n\rlast_block_id\x18\x05 \x01(\x0b\x32\x19.tendermint.types.BlockIDB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12\x18\n\x10last_commit_hash\x18\x06 \x01(\x0c\x12\x11\n\tdata_hash\x18\x07 \x01(\x0c\x12\x17\n\x0fvalidators_hash\x18\x08 \x01(\x0c\x12\x1c\n\x14next_validators_hash\x18\t \x01(\x0c\x12\x16\n\x0e\x63onsensus_hash\x18\n \x01(\x0c\x12\x10\n\x08\x61pp_hash\x18\x0b \x01(\x0c\x12\x19\n\x11last_results_hash\x18\x0c \x01(\x0c\x12\x15\n\revidence_hash\x18\r \x01(\x0c\x12\x18\n\x10proposer_address\x18\x0e \x01(\tB5Z3github.com/cosmos/cosmos-sdk/client/grpc/cmtserviceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.base.tendermint.v1beta1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z3github.com/cosmos/cosmos-sdk/client/grpc/cmtservice'
  _globals['_BLOCK'].fields_by_name['header']._loaded_options = None
  _globals['_BLOCK'].fields_by_name['header']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_BLOCK'].fields_by_name['data']._loaded_options = None
  _globals['_BLOCK'].fields_by_name['data']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_BLOCK'].fields_by_name['evidence']._loaded_options = None
  _globals['_BLOCK'].fields_by_name['evidence']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_HEADER'].fields_by_name['version']._loaded_options = None
  _globals['_HEADER'].fields_by_name['version']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_HEADER'].fields_by_name['chain_id']._loaded_options = None
  _globals['_HEADER'].fields_by_name['chain_id']._serialized_options = b'\342\336\037\007ChainID'
  _globals['_HEADER'].fields_by_name['time']._loaded_options = None
  _globals['_HEADER'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001\250\347\260*\001'
  _globals['_HEADER'].fields_by_name['last_block_id']._loaded_options = None
  _globals['_HEADER'].fields_by_name['last_block_id']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_BLOCK']._serialized_start=248
  _globals['_BLOCK']._serialized_end=479
  _globals['_HEADER']._serialized_start=482
  _globals['_HEADER']._serialized_end=932
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class BridgeEventInfo(_message.Message):
    __slots__ = ("next_id", "eth_block_height")
    NEXT_ID_FIELD_NUMBER: _ClassVar[int]
    ETH_BLOCK_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    next_id: int
    eth_block_height: int
    def __init__(self, next_id: _Optional[int] = ..., eth_block_height: _Optional[int] = ...) -> None: ...



from v4_proto.dydxprotocol.clob import clob_pair_pb2 as _clob_pair_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ClobStagedFinalizeBlockEvent(_message.Message):
    __slots__ = ("create_clob_pair",)
    CREATE_CLOB_PAIR_FIELD_NUMBER: _ClassVar[int]
    create_clob_pair: _clob_pair_pb2.ClobPair
    def __init__(self, create_clob_pair: _Optional[_Union[_clob_pair_pb2.ClobPair, _Mapping]] = ...) -> None: ...



from v4_proto.google.api import annotations_pb2 as _annotations_pb2
from v4_proto.dydxprotocol.delaymsg import delayed_message_pb2 as _delayed_message_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryNextDelayedMessageIdRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryNextDelayedMessageIdResponse(_message.Message):
    __slots__ = ("next_delayed_message_id",)
    NEXT_DELAYED_MESSAGE_ID_FIELD_NUMBER: _ClassVar[int]
    next_delayed_message_id: int
    def __init__(self, next_delayed_message_id: _Optional[int] = ...) -> None: ...

class QueryMessageRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: int
    def __init__(self, id: _Optional[int] = ...) -> None: ...

class QueryMessageResponse(_message.Message):
    __slots__ = ("message",)
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    message: _delayed_message_pb2.DelayedMessage
    def __init__(self, message: _Optional[_Union[_delayed_message_pb2.DelayedMessage, _Mapping]] = ...) -> None: ...

class QueryBlockMessageIdsRequest(_message.Message):
    __slots__ = ("block_height",)
    BLOCK_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    block_height: int
    def __init__(self, block_height: _Optional[int] = ...) -> None: ...

class QueryBlockMessageIdsResponse(_message.Message):
    __slots__ = ("message_ids",)
    MESSAGE_IDS_FIELD_NUMBER: _ClassVar[int]
    message_ids: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, message_ids: _Optional[_Iterable[int]] = ...) -> None: ...



from v4_proto.google.api import annotations_pb2 as _annotations_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ListAllInterfacesRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ListAllInterfacesResponse(_message.Message):
    __slots__ = ("interface_names",)
    INTERFACE_NAMES_FIELD_NUMBER: _ClassVar[int]
    interface_names: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, interface_names: _Optional[_Iterable[str]] = ...) -> None: ...

class ListImplementationsRequest(_message.Message):
    __slots__ = ("interface_name",)
    INTERFACE_NAME_FIELD_NUMBER: _ClassVar[int]
    interface_name: str
    def __init__(self, interface_name: _Optional[str] = ...) -> None: ...

class ListImplementationsResponse(_message.Message):
    __slots__ = ("implementation_message_names",)
    IMPLEMENTATION_MESSAGE_NAMES_FIELD_NUMBER: _ClassVar[int]
    implementation_message_names: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, implementation_message_names: _Optional[_Iterable[str]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/feetiers/genesis.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/feetiers/genesis.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.dydxprotocol.feetiers import params_pb2 as dydxprotocol_dot_feetiers_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#dydxprotocol/feetiers/genesis.proto\x12\x15\x64ydxprotocol.feetiers\x1a\x14gogoproto/gogo.proto\x1a\"dydxprotocol/feetiers/params.proto\"O\n\x0cGenesisState\x12?\n\x06params\x18\x01 \x01(\x0b\x32).dydxprotocol.feetiers.PerpetualFeeParamsB\x04\xc8\xde\x1f\x00\x42<Z:github.com/dydxprotocol/v4-chain/protocol/x/feetiers/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.feetiers.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z:github.com/dydxprotocol/v4-chain/protocol/x/feetiers/types'
  _globals['_GENESISSTATE'].fields_by_name['params']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE']._serialized_start=120
  _globals['_GENESISSTATE']._serialized_end=199
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/accountplus/tx.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/accountplus/tx.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from v4_proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!dydxprotocol/accountplus/tx.proto\x12\x18\x64ydxprotocol.accountplus\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x11\x61mino/amino.proto\"\x8b\x01\n\x13MsgAddAuthenticator\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x1a\n\x12\x61uthenticator_type\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c::\x82\xe7\xb0*\x06sender\x8a\xe7\xb0**dydxprotocol/accountplus/add-authenticator\".\n\x1bMsgAddAuthenticatorResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"s\n\x16MsgRemoveAuthenticator\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x04:=\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*-dydxprotocol/accountplus/remove-authenticator\"1\n\x1eMsgRemoveAuthenticatorResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"\x8e\x01\n\x11MsgSetActiveState\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x0e\n\x06\x61\x63tive\x18\x02 \x01(\x08:<\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*)dydxprotocol/accountplus/set-active-state\"\x1b\n\x19MsgSetActiveStateResponse\".\n\x0bTxExtension\x12\x1f\n\x17selected_authenticators\x18\x01 \x03(\x04\x32\xf7\x02\n\x03Msg\x12x\n\x10\x41\x64\x64\x41uthenticator\x12-.dydxprotocol.accountplus.MsgAddAuthenticator\x1a\x35.dydxprotocol.accountplus.MsgAddAuthenticatorResponse\x12\x81\x01\n\x13RemoveAuthenticator\x12\x30.dydxprotocol.accountplus.MsgRemoveAuthenticator\x1a\x38.dydxprotocol.accountplus.MsgRemoveAuthenticatorResponse\x12r\n\x0eSetActiveState\x12+.dydxprotocol.accountplus.MsgSetActiveState\x1a\x33.dydxprotocol.accountplus.MsgSetActiveStateResponseB?Z=github.com/dydxprotocol/v4-chain/protocol/x/accountplus/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.accountplus.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z=github.com/dydxprotocol/v4-chain/protocol/x/accountplus/types'
  _globals['_MSGADDAUTHENTICATOR']._loaded_options = None
  _globals['_MSGADDAUTHENTICATOR']._serialized_options = b'\202\347\260*\006sender\212\347\260**dydxprotocol/accountplus/add-authenticator'
  _globals['_MSGREMOVEAUTHENTICATOR']._loaded_options = None
  _globals['_MSGREMOVEAUTHENTICATOR']._serialized_options = b'\202\347\260*\006sender\212\347\260*-dydxprotocol/accountplus/remove-authenticator'
  _globals['_MSGSETACTIVESTATE'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGSETACTIVESTATE'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSETACTIVESTATE']._loaded_options = None
  _globals['_MSGSETACTIVESTATE']._serialized_options = b'\202\347\260*\tauthority\212\347\260*)dydxprotocol/accountplus/set-active-state'
  _globals['_MSGADDAUTHENTICATOR']._serialized_start=135
  _globals['_MSGADDAUTHENTICATOR']._serialized_end=274
  _globals['_MSGADDAUTHENTICATORRESPONSE']._serialized_start=276
  _globals['_MSGADDAUTHENTICATORRESPONSE']._serialized_end=322
  _globals['_MSGREMOVEAUTHENTICATOR']._serialized_start=324
  _globals['_MSGREMOVEAUTHENTICATOR']._serialized_end=439
  _globals['_MSGREMOVEAUTHENTICATORRESPONSE']._serialized_start=441
  _globals['_MSGREMOVEAUTHENTICATORRESPONSE']._serialized_end=490
  _globals['_MSGSETACTIVESTATE']._serialized_start=493
  _globals['_MSGSETACTIVESTATE']._serialized_end=635
  _globals['_MSGSETACTIVESTATERESPONSE']._serialized_start=637
  _globals['_MSGSETACTIVESTATERESPONSE']._serialized_end=664
  _globals['_TXEXTENSION']._serialized_start=666
  _globals['_TXEXTENSION']._serialized_end=712
  _globals['_MSG']._serialized_start=715
  _globals['_MSG']._serialized_end=1090
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/clob/streaming.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/clob/streaming.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.dydxprotocol.subaccounts import streaming_pb2 as dydxprotocol_dot_subaccounts_dot_streaming__pb2
from v4_proto.dydxprotocol.prices import streaming_pb2 as dydxprotocol_dot_prices_dot_streaming__pb2
from v4_proto.dydxprotocol.clob import query_pb2 as dydxprotocol_dot_clob_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!dydxprotocol/clob/streaming.proto\x12\x11\x64ydxprotocol.clob\x1a(dydxprotocol/subaccounts/streaming.proto\x1a#dydxprotocol/prices/streaming.proto\x1a\x1d\x64ydxprotocol/clob/query.proto\"\xb6\x02\n\x18StagedFinalizeBlockEvent\x12<\n\norder_fill\x18\x01 \x01(\x0b\x32&.dydxprotocol.clob.StreamOrderbookFillH\x00\x12M\n\x11subaccount_update\x18\x02 \x01(\x0b\x32\x30.dydxprotocol.subaccounts.StreamSubaccountUpdateH\x00\x12\x44\n\x10orderbook_update\x18\x03 \x01(\x0b\x32(.dydxprotocol.clob.StreamOrderbookUpdateH\x00\x12>\n\x0cprice_update\x18\x04 \x01(\x0b\x32&.dydxprotocol.prices.StreamPriceUpdateH\x00\x42\x07\n\x05\x65ventB8Z6github.com/dydxprotocol/v4-chain/protocol/x/clob/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.clob.streaming_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z6github.com/dydxprotocol/v4-chain/protocol/x/clob/types'
  _globals['_STAGEDFINALIZEBLOCKEVENT']._serialized_start=167
  _globals['_STAGEDFINALIZEBLOCKEVENT']._serialized_end=477
# @@protoc_insertion_point(module_scope)
